@@ -600,6 +600,7 @@ class Compare:
                         )
                     )
 
+        match_stats_column_list = []
         if any_mismatch:
             report += "------------------------------------\n"
             report += "值或类型不相等的列\n"
@@ -693,7 +694,7 @@ def render(filename, *fields):
         The fully rendered out file.
     """
     this_dir = os.path.dirname(os.path.realpath(__file__))
-    with open(os.path.join(this_dir, "templates", filename)) as file_open:
+    with open(os.path.join(this_dir, "templates", filename), encoding='utf-8') as file_open:
         return file_open.read().format(*fields)
 
 
